import React__default, { useState, useContext, useRef, useCallback, useLayoutEffect } from 'react';
import useScrollbarSize from 'react-scrollbar-size';
import { ThemeProvider } from '@rescui/ui-contexts';
import Input from '@rescui/input';
import Button from '@rescui/button';
import Switcher from '@rescui/switcher';
import { CloseIcon, ErrorIcon } from '@rescui/icons';
import { useSearch } from '../search-wrapper/use-search.js';
import { ResultsList } from './results-list/results-list.js';
import SearchContext from '../search-wrapper/search-context.js';
import styles from './full-search.module.pcss.js';

const FullSearch = ({
  searchString,
  killSearch
}) => {
  const [isScrollbarCompensated, setIsScrollbarCompensated] = useState(false);
  const [inputValue, setInputValue] = useState(searchString);
  const {
    hits,
    placeholder
  } = useSearch(inputValue, 75);
  const {
    matching,
    matchingOptions,
    setMatching
  } = useContext(SearchContext);
  const ref = useRef(null);
  const headerRef = useRef(null);
  const listRef = useRef(null);
  const isResultsVisible = hits.length > 0 && inputValue;
  const handleSwitcherChange = useCallback(value => {
    setMatching(value);
  }, []);
  const clearSearch = useCallback(() => {
    setInputValue('');
  }, []);
  const handleInputChange = useCallback(e => {
    setInputValue(e.target.value);
  }, [inputValue]); // Scrollbar compensation

  const {
    width
  } = useScrollbarSize();
  useLayoutEffect(() => {
    if (headerRef.current && listRef.current) {
      const countedHeight = headerRef.current.offsetHeight + listRef.current.offsetHeight;

      if (isResultsVisible) {
        setIsScrollbarCompensated(countedHeight < window.innerWidth);
      } else {
        setIsScrollbarCompensated(true);
      }
    }
  }, [hits, inputValue]);
  return React__default.createElement(ThemeProvider, {
    theme: 'light'
  }, React__default.createElement("div", {
    className: styles.fullSearch,
    style: {
      paddingRight: isScrollbarCompensated ? `${width}px` : 0
    },
    tabIndex: 1000,
    ref: ref,
    "data-test": 'full-search'
  }, React__default.createElement("div", {
    className: styles.header,
    ref: headerRef
  }, React__default.createElement("div", {
    className: styles.closeSearch
  }, React__default.createElement(Button, {
    mode: 'clear',
    size: 'l',
    icon: React__default.createElement(CloseIcon, null),
    onClick: killSearch,
    "data-test": 'close-full-search'
  })), React__default.createElement("div", {
    className: styles.wrapper,
    "data-test": 'full-search-input'
  }, React__default.createElement(Input, {
    placeholder: 'Search',
    value: inputValue,
    onChange: handleInputChange,
    onClear: clearSearch,
    clearIcon: React__default.createElement("button", {
      className: styles.fullSearchClearButton
    }, React__default.createElement(ErrorIcon, {
      size: 'l'
    })),
    size: 'l',
    autoFocus: true
  }), isResultsVisible && React__default.createElement("div", {
    className: styles.switcher
  }, React__default.createElement(Switcher, {
    value: matching,
    onChange: handleSwitcherChange,
    options: matchingOptions,
    size: 'xs'
  })))), React__default.createElement("div", {
    className: styles.wrapper,
    ref: listRef
  }, inputValue && React__default.createElement(ResultsList, {
    placeholder: placeholder,
    hits: hits
  }))));
};

export { FullSearch };
