const groupHitsByPageId = ungroupedHits => ungroupedHits.reduce((groups, currentHit) => {
  const currentGroup = groups.find(group => group.name === currentHit.mainTitle);

  if (currentGroup) {
    currentGroup.hits.push(currentHit);
    return groups;
  }

  const newGroup = {
    name: currentHit.mainTitle,
    hits: [currentHit]
  };
  return [...groups, newGroup];
}, []);

const getChapterName = fullName => fullName.split(':')[1] || fullName;

const highlightChaptersTitles = chapters => chapters.map(chapter => ({ ...chapter,
  highlightedTitle: getChapterName(chapter.highlightedTitle)
}));

const getExtendedHits = hits => {
  try {
    const groupedHits = groupHitsByPageId(hits);
    return groupedHits.map(group => {
      const mainHit = group.hits.find(hit => hit.title === group.name);

      if (mainHit) {
        const chapters = group.hits.filter(hit => hit.title !== group.name);
        return { ...mainHit,
          title: mainHit.highlightedTitle,
          chapters: highlightChaptersTitles(chapters)
        };
      }

      const {
        url,
        breadcrumb,
        ...restHitProps
      } = group.hits[0];
      return { ...restHitProps,
        title: group.name,
        url: url.split('#')[0],
        breadcrumb,
        chapters: highlightChaptersTitles(group.hits)
      };
    });
  } catch (error) {
    // reportError(error, { func: 'getExtendedHits' });
    console.log('error');
    return [];
  }
};

export { getExtendedHits as default };
