import React__default from 'react';
import classNames from 'classnames';
import { useTextStyles } from '@rescui/typography';
import getExtendedHits from './get-extended-hits.js';
import { Chapters } from '../chapters/chapters.js';
import styles from './hit-list.module.pcss.js';

const HitList = ({
  hits
}) => {
  const textCn = useTextStyles();
  const extendedHits = getExtendedHits(hits);
  return React__default.createElement("div", {
    "data-test": 'full-search-results'
  }, extendedHits.map(({
    title,
    snippet,
    chapters = [],
    url,
    breadcrumb
  }, pageIndex) => {
    const isHitWithChapters = chapters.length > 0;
    return React__default.createElement("div", {
      className: styles.hitList,
      key: pageIndex
    }, React__default.createElement("h3", {
      className: textCn('rs-h3')
    }, React__default.createElement("a", {
      className: classNames(styles.titleLink, textCn('rs-link', {
        mode: 'clear',
        hardness: 'hard'
      })),
      href: url,
      dangerouslySetInnerHTML: {
        __html: title
      }
    })), isHitWithChapters ? React__default.createElement(Chapters, {
      chapters: chapters,
      hitIndex: pageIndex
    }) : React__default.createElement("div", {
      className: classNames(textCn('rs-text-2'), styles.snippet),
      dangerouslySetInnerHTML: {
        __html: snippet
      }
    }));
  }));
};

export { HitList };
