import classNames from 'classnames';
import React__default, { useState, useEffect } from 'react';
import styles from './horizontal-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';

const DropdownMenu = ({
  items,
  isExpanded,
  alignRight,
  linkHandler
}) => {
  const textCn = useTextStyles();
  return React__default.createElement("ul", {
    className: classNames(styles.dropdownMenu, textCn('rs-text-2'), {
      [styles.dropdownMenuExpanded]: isExpanded,
      [styles.dropdownMenuAlignRight]: alignRight
    })
  }, items.map((item, key) => {
    const Tag = !item.isActive && item.url ? 'a' : 'span';
    return React__default.createElement("li", {
      key: key
    }, React__default.createElement(Tag, Object.assign({
      className: classNames(styles.dropdownMenuItem, {
        [styles.active]: item.isActive
      })
    }, item.url ? {
      href: item.url,
      onClick: linkHandler ? event => item.url && linkHandler(event, item.url) : undefined
    } : {}), item.title));
  }));
};

const HorizontalMenuItem = ({
  item,
  onMouseEnter,
  onMouseLeave,
  isExpanded,
  isLast,
  linkHandler
}) => {
  const Tag = item.isActive || !item.url ? 'span' : 'a';
  const textCn = useTextStyles();

  const handleEnter = () => onMouseEnter(item);

  return React__default.createElement("li", {
    className: styles.menuItemWrap,
    onMouseEnter: handleEnter,
    onMouseLeave: onMouseLeave
  }, React__default.createElement(Tag, Object.assign({}, item.url ? {
    href: item.url,
    onClick: linkHandler ? event => item.url && linkHandler(event, item.url) : undefined
  } : {}, {
    key: item.title,
    className: classNames(styles.menuItem, textCn('rs-text-2'), {
      [styles.itemActive]: item.isActive,
      [styles.expanded]: isExpanded && !!item.items?.length
    })
  }), item.title), !!item.items?.length && React__default.createElement(DropdownMenu, {
    items: item.items,
    isExpanded: isExpanded,
    alignRight: isLast,
    linkHandler: linkHandler
  }));
};

const HorizontalMenu = ({
  items,
  theme,
  linkHandler
}) => {
  const [activeIndex, setActiveIndex] = useState(-1);
  const [debouncedActiveIndex, setDebouncedActiveIndex] = useState(activeIndex);
  useEffect(() => {
    const handler = setTimeout(() => setDebouncedActiveIndex(activeIndex), activeIndex !== -1 ? 200 : 400);
    return () => clearTimeout(handler);
  }, [activeIndex]);

  const handleEnter = item => setActiveIndex(items.findIndex(val => val === item));

  const handleLeave = () => setActiveIndex(-1);

  return React__default.createElement("nav", {
    className: classNames(styles.nav, {
      [styles.darkTheme]: theme === 'dark'
    })
  }, React__default.createElement("ul", {
    className: styles.menuList
  }, items.map((item, index) => React__default.createElement(HorizontalMenuItem, {
    item: item,
    onMouseEnter: handleEnter,
    onMouseLeave: handleLeave,
    isExpanded: index === debouncedActiveIndex,
    isLast: index === items.length - 1,
    key: index,
    linkHandler: linkHandler
  }))));
};

export { HorizontalMenu };
