import React__default, { useRef, useState, useEffect, useLayoutEffect, useCallback, Fragment } from 'react';
import styles from './menu-popup.module.pcss.js';
import classNames from 'classnames';
import { MenuButton } from './menu-button/menu-button.js';
import { useTextStyles } from '@rescui/typography';
import { clearAllBodyScrollLocks, enableBodyScroll, disableBodyScroll } from 'body-scroll-lock';

const MenuListItem = ({
  item,
  level,
  linkHandler
}) => {
  const Tag = item.url ? 'a' : 'span';
  const style = {
    '--level': level
  };
  const handleClick = useCallback(event => linkHandler && item.url && linkHandler(event, item.url), []);
  return React__default.createElement(Tag, Object.assign({}, item.url ? {
    href: item.url,
    onClick: handleClick
  } : {}, {
    className: classNames(styles.menuItem, {
      [styles.menuItemRoot]: level === 0,
      [styles.active]: item.isActive,
      [styles.activeWithChild]: item.items && item.items.length
    }),
    style: style
  }), item.title);
};

const MenuList = ({
  items,
  level,
  linkHandler
}) => {
  return React__default.createElement(React__default.Fragment, null, items.map((item, i) => React__default.createElement(Fragment, {
    key: i
  }, React__default.createElement(MenuListItem, {
    item: item,
    level: level,
    linkHandler: linkHandler
  }), item.items && item.items.length > 0 && React__default.createElement(MenuList, {
    items: item.items,
    level: level + 1,
    linkHandler: linkHandler
  }))));
};

const MenuPopup = ({
  items,
  isExpanded,
  setExpand,
  headerRef,
  linkHandler
}) => {
  const navRef = useRef(null);
  const textCn = useTextStyles();
  const [navStyle, setNavStyle] = useState({});
  useEffect(() => {
    return () => {
      setExpand(false);
      clearAllBodyScrollLocks();
    };
  }, []);
  useLayoutEffect(() => {
    if (headerRef.current) {
      setNavStyle({
        top: headerRef.current.getBoundingClientRect().bottom
      });
    }
  }, [isExpanded, headerRef]);
  const handleClick = useCallback(() => {
    if (navRef.current) {
      isExpanded ? enableBodyScroll(navRef.current) : disableBodyScroll(navRef.current);
    }

    setExpand(!isExpanded);
  }, [isExpanded, navRef]);
  return React__default.createElement(React__default.Fragment, null, React__default.createElement(MenuButton, {
    onClick: handleClick,
    isExpanded: isExpanded
  }), React__default.createElement("nav", {
    style: navStyle,
    ref: navRef,
    className: classNames(styles.menuPopup, textCn('rs-text-2'), {
      [styles.menuPopupExpanded]: isExpanded
    })
  }, React__default.createElement(MenuList, {
    items: items,
    level: 0,
    linkHandler: linkHandler
  })));
};

export { MenuPopup };
