import React__default from 'react';
import { ThemeProvider } from '@rescui/ui-contexts';
import classNames from 'classnames';
import { ResultsList } from './list/list.js';
import { EmptyResult } from './empty/empty.js';
import { LoadingResults } from './loading/loading.js';
import styles from './quick-search.module.pcss.js';

const QuickSearch = ({
  results,
  searchString,
  toggleFullSearch,
  placeholder,
  quickSearchBoxViewType
}) => {
  const wrapperClassName = classNames(styles.wrapper, {
    [styles.apiReferenceWrapper]: quickSearchBoxViewType
  });

  if (placeholder) {
    return React__default.createElement(ThemeProvider, {
      theme: 'dark'
    }, React__default.createElement("div", {
      className: wrapperClassName
    }, React__default.createElement(EmptyResult, {
      placeholder: placeholder
    })));
  }

  if (results.length > 0) {
    return React__default.createElement(ThemeProvider, {
      theme: 'dark'
    }, React__default.createElement("div", {
      className: wrapperClassName
    }, React__default.createElement(ResultsList, {
      results: results,
      searchString: searchString,
      toggleFullSearch: toggleFullSearch,
      resultListViewType: quickSearchBoxViewType
    })));
  }

  return React__default.createElement("div", {
    className: wrapperClassName
  }, React__default.createElement(LoadingResults, null));
};

export { QuickSearch };
