import React__default, { useState, useCallback, useEffect } from 'react';
import Input from '@rescui/input';
import { SearchIcon, CloseIcon, ErrorIcon } from '@rescui/icons';
import { QuickSearch } from '../quick-search/quick-search.js';
import { FullSearch } from '../full-search/full-search.js';
import styles from './search-box.module.pcss.js';
import { useSearch } from '../search-wrapper/use-search.js';
import { ESC_CODE } from '../key-codes.js';

const SearchBox = ({
  closeHandler,
  isMobile,
  fullSearchActive,
  setFullSearchActive,
  searchBoxViewType
}) => {
  const [searchInput, setSearchInput] = useState('');
  const {
    hits,
    placeholder
  } = useSearch(searchInput, fullSearchActive ? 25 : 75);
  const escHandler = useCallback(event => {
    if (event.keyCode === ESC_CODE) {
      closeHandler();
    }
  }, [closeHandler]);
  const handleInput = useCallback(e => {
    setSearchInput(e.target.value);
  }, []);
  const handleClear = useCallback(() => {
    setSearchInput('');
  }, []);
  const toggleFullSearch = useCallback(() => {
    setFullSearchActive(!fullSearchActive);
  }, [fullSearchActive]);
  useEffect(() => {
    if (typeof document !== `undefined`) {
      document.addEventListener('keydown', escHandler);
      return () => {
        document.removeEventListener('keydown', escHandler);
      };
    }
  }, [escHandler]);
  return React__default.createElement("div", {
    className: styles.searchBox
  }, React__default.createElement("div", {
    className: styles.searchInput,
    "data-test": 'quick-search-input'
  }, React__default.createElement(Input, {
    iconType: 'left',
    value: searchInput,
    onChange: handleInput,
    onClear: isMobile ? closeHandler : handleClear,
    icon: React__default.createElement(SearchIcon, null),
    clearIcon: isMobile ? React__default.createElement(CloseIcon, null) : React__default.createElement("button", {
      className: styles.customClearButton
    }, React__default.createElement(ErrorIcon, null)),
    autoFocus: true
  }), isMobile && React__default.createElement("button", {
    className: styles.searchMobileClose,
    onClick: closeHandler
  }, React__default.createElement(CloseIcon, null))), searchInput && React__default.createElement(QuickSearch, {
    results: hits,
    searchString: searchInput,
    toggleFullSearch: toggleFullSearch,
    placeholder: placeholder,
    quickSearchBoxViewType: searchBoxViewType
  }), fullSearchActive && React__default.createElement(FullSearch, {
    toggleFullSearch: toggleFullSearch,
    searchString: searchInput,
    results: hits,
    killSearch: closeHandler
  }));
};

export { SearchBox };
