import algoliasearch from 'algoliasearch/lite';
import { EXACT_MATCH } from './search-const.js';
import { searchWithAlgolia } from './search-with-algolia.js';
import { useState, useEffect, useMemo } from 'react';
const attributesToRetrieve = ['pageTitle', 'url', 'breadcrumbs', 'mainTitle'];
const attributesToSnippet = ['content:25'];

function initSearch({
  searchAlgoliaId,
  searchAlgoliaApiKey,
  searchAlgoliaIndexName
}) {
  const [searchIndex, setSearchIndex] = useState(null);
  useEffect(() => {
    if (searchAlgoliaId && searchAlgoliaApiKey && searchAlgoliaIndexName) {
      const algoliaClient = algoliasearch(searchAlgoliaId, searchAlgoliaApiKey);
      setSearchIndex(algoliaClient.initIndex(searchAlgoliaIndexName));
    }
  }, []);
  const search = useMemo(() => async (query, matching, maxHits) => {
    try {
      const isExactSearch = matching === EXACT_MATCH.value;
      const searchArgs = {
        attributesToRetrieve,
        attributesToSnippet,
        isExactSearch,
        maxHits,
        query
      };

      if (!searchIndex) {
        throw new Error('ConfigData is empty');
      }

      const searchData = await searchWithAlgolia({ ...searchArgs,
        searchIndex
      });
      const {
        hits,
        totalHits
      } = searchData;
      return {
        hits,
        totalHits
      };
    } catch (error) {
      //reportError(error, { component: 'search' });
      return {
        hits: [],
        totalHits: 0
      };
    }
  }, [searchIndex]);
  return {
    searchIndex,
    search
  };
}

export { initSearch };
