const snippetEllipsisText = '…';

const searchWithAlgolia = async ({
  attributesToRetrieve = [],
  attributesToSnippet = [],
  isExactSearch = false,
  maxHits = 0,
  query = '',
  searchIndex
}) => {
  try {
    if (searchIndex?.indexName) {
      const searchResponse = await searchIndex.search(query, {
        attributesToRetrieve,
        attributesToSnippet,
        clickAnalytics: true,
        hitsPerPage: maxHits,
        query,
        snippetEllipsisText,
        typoTolerance: !isExactSearch
      });
      return {
        hits: mapResponseToHits(searchResponse.hits),
        totalHits: searchResponse.nbHits
      };
    }

    throw new Error(`Algolia client can't be initialized`);
  } catch (error) {
    return {
      totalHits: 0,
      hits: []
    };
  }
};

function mapResponseToHits(results) {
  return results.map(({
    _highlightResult,
    _snippetResult,
    breadcrumbs,
    mainTitle,
    objectID,
    pageTitle,
    url
  }) => ({
    breadcrumb: breadcrumbs,
    highlightedTitle: _highlightResult.pageTitle.value,
    hitId: objectID,
    mainTitle,
    pageId: _highlightResult.parent.value,
    snippet: _snippetResult.content.value,
    title: pageTitle,
    url
  }));
}

export { searchWithAlgolia };
