import React__default, { useState, useCallback } from 'react';
import SwipeableViews from 'react-swipeable-views';
import cn from 'classnames';
import SvgQuote from './quote.svg.js';
import SvgSliderArrow from './slider-arrow.svg.js';
import styles from './quotes-slider.module.pcss.js';

const QuotesSlider = ({
  quotes,
  large
}) => {
  const [index, setIndex] = useState(0);
  const totalSlides = quotes.length;
  const handleNextSlide = useCallback(() => {
    if (index + 1 < totalSlides) {
      setIndex(index + 1);
    }
  }, [index]);
  const handlePrevSlide = useCallback(() => {
    if (index > 0) {
      setIndex(index - 1);
    }
  }, [index]);
  const handleChangeIndex = useCallback(i => {
    setIndex(i);
  }, [index]);
  const slideTitle = quotes[index].title;
  const prevButtonClass = cn([styles.control, styles.controlPrev], {
    [styles.controlActive]: index > 0
  });
  const nextButtonClass = cn(styles.control, {
    [styles.controlActive]: index + 1 < totalSlides
  });
  const quoteTextClass = large ? 'ktl-subtitle' : 'ktl-text-1';
  return React__default.createElement("div", {
    className: styles.quotesSlider
  }, React__default.createElement("div", {
    className: styles.content
  }, React__default.createElement("div", {
    className: styles.iconContainer
  }, React__default.createElement(SvgQuote, null)), React__default.createElement("div", null, quotes.length > 1 ? React__default.createElement(SwipeableViews, {
    index: index,
    onChangeIndex: handleChangeIndex
  }, quotes.map((quote, i) => React__default.createElement("p", {
    className: quoteTextClass,
    key: i
  }, quote.text))) : React__default.createElement("p", {
    className: quoteTextClass
  }, quotes[0].text), React__default.createElement("div", {
    className: styles.nav
  }, React__default.createElement("div", {
    className: styles.title
  }, React__default.createElement("p", {
    className: "ktl-text-2"
  }, slideTitle)), quotes.length > 1 && React__default.createElement("div", {
    className: styles.controls
  }, React__default.createElement("div", {
    className: prevButtonClass,
    onClick: handlePrevSlide
  }, React__default.createElement(SvgSliderArrow, null)), React__default.createElement("div", {
    className: styles.slidesCount
  }, React__default.createElement("p", {
    className: "ktl-text-2"
  }, index + 1, "/", totalSlides)), React__default.createElement("div", {
    className: nextButtonClass,
    onClick: handleNextSlide
  }, React__default.createElement(SvgSliderArrow, null)))))));
};

export { QuotesSlider };
