import React__default, { useState } from 'react';
import ReactDOM from 'react-dom';
import classNames from 'classnames';
import styles from './dropdown-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';
import SvgArrowDropdownIcon from './arrow-dropdown-icon.svg.js';
import { useTheme } from '@rescui/ui-contexts';

const DropdownMenu = ({
  homeUrl,
  title,
  mobileTitle = 'Overview',
  items,
  activeIndex,
  linkHandler,
  mobileOverview = true
}) => {
  const theme = useTheme();
  const textCn = useTextStyles();
  const [portalRoot, setPortalRoot] = React__default.useState(null);
  React__default.useEffect(() => {
    if (typeof document !== `undefined`) {
      setPortalRoot(document.body);
    }
  }, []);

  let _items = (mobileOverview ? [{
    title: mobileTitle,
    url: homeUrl
  }] : []).concat(items);

  const _activeIndex = mobileOverview ? activeIndex + 1 : activeIndex;

  const activeItem = _items[_activeIndex];
  const [isExpanded, setIsExpanded] = useState(false);

  const handleClick = () => setIsExpanded(!isExpanded);

  return React__default.createElement(React__default.Fragment, null, React__default.createElement("div", {
    className: classNames(styles.dropdownMenu, {
      [styles.dropdownMenuExpanded]: isExpanded
    }),
    onClick: handleClick
  }, React__default.createElement("button", {
    className: classNames(styles.button, textCn('rs-text-2')),
    "aria-haspopup": "true"
  }, React__default.createElement("span", {
    className: styles.buttonText
  }, activeItem.title), React__default.createElement(SvgArrowDropdownIcon, {
    className: styles.icon
  })), React__default.createElement("nav", {
    className: classNames(styles.dropdownList, {
      [styles.dropdownListDarkTheme]: theme === 'dark'
    })
  }, _items.map((item, index) => React__default.createElement("a", {
    key: item.url,
    href: item.url,
    className: classNames(styles.dropdownItem, textCn('rs-text-2'), {
      [styles.dropdownItemActive]: index === _activeIndex
    }),
    onClick: event => linkHandler?.(event, item.url),
    target: item.isExternal ? '_blank' : undefined
  }, item.title)))), !!portalRoot && ReactDOM.createPortal(React__default.createElement("div", {
    className: classNames(styles.overlay, {
      [styles.overlayVisible]: isExpanded
    }),
    onClick: handleClick
  }), portalRoot));
};

export { DropdownMenu };
