import React__default, { useCallback } from 'react';
import classNames from 'classnames';
import styles from './horizontal-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';

const HorizontalMenuItem = ({
  item,
  isActive,
  linkHandler
}) => {
  const textCn = useTextStyles();
  const handleLink = useCallback(event => linkHandler(event, item.url), [item]);
  return isActive ? React__default.createElement("span", {
    key: item.url,
    className: styles.itemActive
  }, item.title) : React__default.createElement("a", {
    href: item.url,
    key: item.url,
    className: classNames(styles.item, textCn('rs-link', {
      hardness: 'average',
      mode: 'clear'
    })),
    onClick: handleLink,
    target: item.isExternal ? '_blank' : undefined
  }, item.title);
};

const HorizontalMenu = ({
  items,
  activeIndex,
  linkHandler
}) => {
  const textCn = useTextStyles();
  return React__default.createElement("nav", {
    className: classNames(styles.horizontalMenu, textCn('rs-text-2'))
  }, items.map((item, index) => React__default.createElement(HorizontalMenuItem, {
    key: item.url,
    isActive: index === activeIndex,
    item: item,
    linkHandler: linkHandler
  })));
};

export { HorizontalMenu };
