import React__default from 'react';
import { useTheme } from '@rescui/ui-contexts';
import classNames from 'classnames';
import styles from './top-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';
import { HorizontalMenu } from './horizontal-menu/horizontal-menu.js';
import { DropdownMenu } from './dropdown-menu/dropdown-menu.js';

const TopMenu = ({
  homeUrl,
  title,
  mobileTitle,
  activeIndex,
  items,
  linkHandler = () => {},
  className,
  children,
  forwardedRef,
  mobileOverview
}) => {
  const theme = useTheme();
  const textCn = useTextStyles();
  return React__default.createElement("div", {
    className: classNames(styles.topMenu, className, {
      [styles.topMenuDarkTheme]: theme === 'dark'
    }),
    ref: forwardedRef
  }, React__default.createElement("a", {
    href: homeUrl,
    className: classNames(styles.logo, textCn('rs-h3')),
    onClick: event => linkHandler(event, homeUrl)
  }, title), React__default.createElement(DropdownMenu, {
    items: items,
    activeIndex: activeIndex,
    linkHandler: linkHandler,
    title: title,
    mobileTitle: mobileTitle,
    homeUrl: homeUrl,
    mobileOverview: mobileOverview
  }), React__default.createElement(HorizontalMenu, {
    items: items,
    activeIndex: activeIndex,
    linkHandler: linkHandler
  }), children);
};

export { TopMenu };
