import cookie from 'cookie';
import shajs from 'sha.js';
const submitURL = 'https://forms-service.jetbrains.com/marketo';
const munchkinId = '426-QVD-114';

function getChecksum(obj) {
  const values = [];
  const fields = [];
  Object.entries(obj).slice(0, 20).forEach(([key, value]) => {
    values.push(value);
    fields.push(key);
  });
  const checksum = shajs('sha256').update(values.join('|')).digest('hex');
  return {
    checksumFields: fields.join(','),
    checksum
  };
}

function submitToMarketo(data) {
  const submitData = data;
  const formId = submitData.formid;

  if (!formId) {
    throw new Error('`formid` should be specified');
  }

  submitData.munchkinId = munchkinId;

  if (!('formVid' in submitData)) {
    submitData.formVid = formId;
  }

  const mktTrk = cookie.parse(document.cookie)._mkto_trk;

  if (mktTrk) {
    // eslint-disable-next-line camelcase
    submitData._mkt_trk = mktTrk;
  }

  const {
    checksum,
    checksumFields
  } = getChecksum(submitData);
  const dataToSend = { ...submitData,
    checksum,
    checksumFields
  };
  let formSubmitData;
  formSubmitData = JSON.stringify(dataToSend);
  return fetch(submitURL, {
    method: 'POST',
    body: formSubmitData,
    headers: {
      accept: `application/json, text/javascript, */*; q=0.01`,
      'Content-Type': 'application/json'
    },
    referrerPolicy: 'strict-origin-when-cross-origin'
  });
}

export { submitToMarketo };
