import { stringify } from 'query-string';
import ConsentId from './privacy-consent-ids.json.js';

class PrivacyConsentService {
  constructor(urls) {
    this.urls = urls;
    this.ConsentId = ConsentId;
  }

  getConsentOptions(consentId, requestParams = {}) {
    let params;

    if (typeof requestParams === 'string') {
      console.warn(`getConsentOptions(consentId, countryCode) method signature is deprecated,` + ` please use getConsentOptions(consentId, requestParams). For this call it should be "getConsentOptions(${consentId}, { country: ${requestParams} })" instaed of` + ` "getConsentOptions(${consentId}, ${requestParams})", same applicable for getShortMessage and getMessage methods witch is using getConsentOptions under the hood.`);
      params = {
        country: requestParams.toUpperCase(),
        consentId
      };
    } else {
      params = { ...requestParams,
        consentId
      };
    }

    const url = `${this.urls.getMessage}?${stringify(params)}`;
    return fetch(url).then(res => res.json());
  }

  sendAcceptance(consentId, email, {
    useNewEndpoint = false
  } = {}) {
    const params = {
      type: consentId,
      email
    };
    const url = `${useNewEndpoint ? this.urls.newSendAcceptance : this.urls.sendAcceptance}?${stringify(params)}`;
    return fetch(url, {
      method: 'POST'
    });
  }

}

export { PrivacyConsentService as default };
